<?php

@set_time_limit(0);

/**
* Bulk domain availablity check script (Revision 7)		
*
* Created  by "Matthew." (up to revision 6) (45276) @ http://namepros.com / http://mattjewell.com
* Modified by "Eric"     (revision 7)       (14781) @ http://namepros.com / http://secondversion.com
*
* Feel free to modify/use however you wish, but keep credit comments in upon distribution.
*/

/**
* Changes by "Eric" (Eric Sizemore)
*
* Revision 7, October 13th, 2009
* -------------------------------------
* - Added blank index pages in the saves and inc directory.
* - Minor enhancements to the php code, to hopefully improve speed.
* - Should be valid HTML now.
*/

require_once('./inc/dnservers.php');

/**
* Saves domain status (available/taken/or invalid) to a text file.
*
* @param  string  Domain status
* @return void
*/
function save_file($status)
{
	global $filename, $domain, $extension;

	$domain = trim($domain);

	if (!($file_handle = @fopen($filename . "_$status.txt", 'a+')))
	{
		trigger_error('Cannot open or create file (chmod?)', E_USER_WARNING);
	}

	if ($status == 'invalid' AND $extension == 'org')
	{
		$status .= ' (.org WHOIS prevents request)';
	}

	if (!fwrite($file_handle, "$domain is $status\n"))
	{
		trigger_error("Results for $domain could not be written.", E_USER_WARNING);
	}
	fclose($file_handle);
}

/**
* Returns domain status (available/taken/or invalid).
*
* @param  string  Domain name
* @param  string  Domain status
* @return void
*/
function return_status($domain, $status)
{
	global $extension, $filename;

	$file = $filename;
	$domain = trim($domain);

	if (isset($_POST['save']))
	{
		save_file($status);
	}
	else
	{
		$color = ($status == 'available') ? '#008000' : '#FF0000';

		if ($status == 'invalid' AND $extension == 'org')
		{
			$status .= ' (.org WHOIS prevents request)';
		}
		echo "<div style=\"color: $color;\">$domain is $status!</div>\n";
	}
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<title>Bulk Domain Availability Check</title>
</head>

<body>

<?php

/** */
if (isset($_POST['submit']))
{
	$filename = 'saves/' . mt_rand(5, 99999999999);

	if (strlen($_POST['domains']) > 0)
	{
		$domains = preg_split("#\n#", trim($_POST['domains']), -1, PREG_SPLIT_NO_EMPTY);

		ob_start();

		echo '<h1>Checking ' . count($domains) . ' domains</h1><br />' . "\n";
		echo (isset($_POST['save'])) ? 'Preparing results, please wait...<br /><br />' . "\n" : '';

		foreach ($domains AS $domain)
		{
			unset($buffer); // clean buffer - prevents problems

			// (replaced str_replace)
			preg_match('@^(http://www\.|http://|www\.)?([^/]+)@i', $domain, $matches);
			$domain = $matches[2];

			$tld = explode('.', $domain, 2);
			$extension = strtolower(trim($tld[1]));

			if (strlen($domain) > 0 AND isset($ext[".$extension"]))
			{
				$server = $ext[".$extension"][0];

				if (!($sock = @fsockopen($server, 43)))
				{
					trigger_error("Error Connecting To Server: $server", E_USER_WARNING);
				}

				fputs($sock, "$domain\r\n");

				while (!feof($sock))
				{
					$buffer .= fgets($sock, 128);
				}
				fclose($sock);

				if ($extension == 'org')
				{
					echo nl2br($buffer);
				}

				if (substr_count($buffer, $ext[".$extension"][1]) > 0)
				{
					return_status($domain, 'available');
				}
				else
				{
					return_status($domain, 'taken');
				}
			}
			else
			{
				if (strlen($domain) > 0)
				{
					return_status($domain, 'invalid');
				}
			}

			ob_flush(); // output before checking next domain
			flush();
			sleep(0.01);
		}

		@ob_end_flush();

		if (isset($_POST['save']) AND count($domains) > 0)
		{
			echo 'Check completed, your results can be found below:' . "\n";

			if (file_exists("{$filename}_available.txt"))
			{
				echo '<br /><a href="' . $filename . '_available.txt">Available domains</a>' . "\n";
			}

			if (file_exists("{$filename}_taken.txt"))
			{
				echo '<br /><a href="' . $filename . '_taken.txt">Taken domains</a>' . "\n";
			}
			else
			{
				echo '<br />0 taken domains found' . "\n";
			}

			if (file_exists("{$filename}_invalid.txt"))
			{
				echo '<br /><a href="' . $filename . '_invalid.txt">Invalid domains (could not be checked)</a>' . "\n";
			}
		}
	}
	else
	{
		echo 'You need to enter one or more domains!';
	}
}
else
{
?>
<div style="text-align: center;">
	<form action="index.php" method="post">
	<p>
		<textarea name="domains" cols="100" rows="20"></textarea><br />
		<input type="checkbox" name="save" id="save" value="save" /> <label for="save">Save results as text file?</label><br /><br />
		<input type="submit" name="submit" value="Check Availability" style="font-size: 30pt;" />
	</p>
	</form>
</div>
<?php
}
?>

</body>
</html>